@@ -6,6 +6,7 @@ import json
 import os
 import re
 import sys
+import threading
 from collections.abc import Callable, Generator
 from io import StringIO
 from signal import SIGINT, signal
@@ -378,6 +379,7 @@ class Resource(ResourceConstants):
         POLICY: str = "policy"
         POOL_KUBEVIRT_IO: str = "pool.kubevirt.io"
         PROJECT_OPENSHIFT_IO: str = "project.openshift.io"
+        QUOTA_OPENSHIFT_IO: str = "quota.openshift.io"
         RBAC_AUTHORIZATION_K8S_IO: str = "rbac.authorization.k8s.io"
         REMEDIATION_MEDIK8S_IO: str = "remediation.medik8s.io"
         RIPSAW_CLOUDBULLDOZER_IO: str = "ripsaw.cloudbulldozer.io"
@@ -582,7 +584,8 @@ class Resource(ResourceConstants):
         self._base_body()
 
     def __enter__(self) -> Any:
-        signal(SIGINT, self._sigint_handler)
+        if threading.current_thread().native_id == threading.main_thread().native_id:
+            signal(SIGINT, self._sigint_handler)
         return self.deploy(wait=self.wait_for_resource)
 
     def __exit__(
